Module entity
this
0.0.9
Module entity
Module Items
Traits
In this::
core
this
::
core
Module
entity
Entity traits defining the core abstraction for all data types
Traits

Data
Trait for data entities that represent concrete domain objects.
Entity
Base trait for all entities in the system.
Link
Trait for link entities that represent relationships between entities.